@@ -4,11 +4,7 @@
 #include <QCommandLineParser>
 #include <QIcon>
 
-#if defined Q_OS_MACOS || defined Q_OS_WIN
-#include <KF5/KI18n/KLocalizedString>
-#else
 #include <KI18n/KLocalizedString>
-#endif
 
 #if defined Q_OS_ANDROID || defined Q_OS_IOS
 #include <QGuiApplication>
@@ -27,7 +23,7 @@
 #endif
 
 #ifdef Q_OS_MACOS
-#include "mauimacos.h"
+#include <MauiKit/Core/mauimacos.h>
 #endif
 
 #include <MauiKit/FileBrowsing/fmstatic.h>
@@ -35,8 +31,6 @@
 
 #include "../vvave_version.h"
 
-#include "utils/bae.h"
-
 #include "vvave.h"
 
 #include "services/local/artworkprovider.h"
@@ -56,9 +50,7 @@
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
 
 #ifdef Q_OS_WIN32
     qputenv("QT_MULTIMEDIA_PREFERRED_PLUGINS", "w");
@@ -78,11 +70,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon("qrc:/assets/vvave.png"));
 
-    MauiApp::instance()->setHandleAccounts(true); // for now pix can not handle cloud accounts
     MauiApp::instance()->setIconName("qrc:/assets/vvave.png");
 
     KLocalizedString::setApplicationDomain("vvave");
-    KAboutData about(QStringLiteral("vvave"), i18n("Vvave"), VVAVE_VERSION_STRING, i18n("Vvave lets you organize, browse and listen to your local and online music collection."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())),QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("vvave"), i18n("Vvave"), VVAVE_VERSION_STRING, i18n("Play your music collection."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())),QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
@@ -119,7 +110,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterSingletonInstance<vvave>(VVAVE_URI, 1, 0, "Vvave", vvave::instance());
 
     qmlRegisterType<TracksModel>(VVAVE_URI, 1, 0, "Tracks");
-    qmlRegisterType<PlaylistsModel>(VVAVE_URI, 1, 0, "Playlists");
     qmlRegisterType<AlbumsModel>(VVAVE_URI, 1, 0, "Albums");
     qmlRegisterType<Cloud>(VVAVE_URI, 1, 0, "Cloud");
     qmlRegisterType<FoldersModel>(VVAVE_URI, 1, 0, "Folders");
@@ -131,6 +121,12 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<TrackInfo>(VVAVE_URI, 1, 0, "TrackInfo");
     qmlRegisterType<MetadataEditor>(VVAVE_URI, 1, 0, "MetadataEditor");
 
+    qmlRegisterSingletonType<PlaylistsModel>(VVAVE_URI, 1, 0, "Playlists", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
+        Q_UNUSED(scriptEngine)
+        Q_UNUSED(engine)
+           return new PlaylistsModel;
+       });
+
     engine.addImageProvider("artwork", new ArtworkProvider());
 
 #if defined Q_OS_LINUX && !defined Q_OS_ANDROID
