@@ -11,7 +11,6 @@ class PlaylistsModel : public MauiList
 public:
     explicit PlaylistsModel(QObject *parent = nullptr);
     const FMH::MODEL_LIST &items() const override;
-    void componentComplete() override;
 
 private:
     FMH::MODEL_LIST list;
@@ -27,7 +26,6 @@ signals:
     void fileTagged(QUrl url, QString playlist);
 
 public slots:
-    QVariantMap get(const int &index) const;
     void insert(const QString &playlist);
 
     void addTrack(const QString &playlist, const QStringList &urls);
