@@ -93,14 +93,6 @@ void TracksModel::setList()
     }
 }
 
-void TracksModel::copy(const TracksModel *model)
-{
-    emit this->preListChanged();
-    this->list << model->getItems();
-    emit this->postListChanged();
-    emit this->countChanged();
-}
-
 void TracksModel::append(const QVariantMap &item)
 {
     if (item.isEmpty())
@@ -135,6 +127,19 @@ void TracksModel::appendQuery(const QString &query)
     emit this->countChanged();
 }
 
+void TracksModel::copy(const TracksModel *list)
+{
+    if(!list)
+    {
+        return;
+    }
+
+    emit this->preItemsAppended(list->getCount());
+    this->list <<  list->items();
+    emit this->postItemAppended();
+    emit this->countChanged();
+}
+
 void TracksModel::clear()
 {
     emit this->preListChanged();
@@ -148,17 +153,15 @@ bool TracksModel::fav(const int &index, const bool &value)
     if (index >= this->list.size() || index < 0)
         return false;
 
-    const auto index_ = this->mappedIndex(index);
-
-    auto item = this->list[index_];
+    auto item = this->list[index];
 
     if (value)
         Tagging::getInstance()->fav(item[FMH::MODEL_KEY::URL]);
     else
         Tagging::getInstance()->unFav(item[FMH::MODEL_KEY::URL]);
 
-    this->list[index_][FMH::MODEL_KEY::FAV] = value ? "1" : "0";
-    emit this->updateModel(index_, {FMH::MODEL_KEY::FAV});
+    this->list[index][FMH::MODEL_KEY::FAV] = value ? "1" : "0";
+    emit this->updateModel(index, {FMH::MODEL_KEY::FAV});
 
     return true;
 }
@@ -168,12 +171,10 @@ bool TracksModel::countUp(const int &index)
     if (index >= this->list.size() || index < 0)
         return false;
 
-    const auto index_ = this->mappedIndex(index);
-
-    auto item = this->list[index_];
+    auto item = this->list[index];
     if (this->db->playedTrack(item[FMH::MODEL_KEY::URL])) {
-        this->list[index_][FMH::MODEL_KEY::COUNT] = QString::number(item[FMH::MODEL_KEY::COUNT].toInt() + 1);
-        emit this->updateModel(index_, {FMH::MODEL_KEY::COUNT});
+        this->list[index][FMH::MODEL_KEY::COUNT] = QString::number(item[FMH::MODEL_KEY::COUNT].toInt() + 1);
+        emit this->updateModel(index, {FMH::MODEL_KEY::COUNT});
 
         return true;
     }
@@ -188,13 +189,8 @@ bool TracksModel::remove(const int &index)
     if (index >= this->list.size() || index < 0)
         return false;
 
-
-    const auto index_ = this->mappedIndex(index);
-
-    qDebug() << "REMOVE AT" << index << index_;
-
-    emit this->preItemRemoved(index_);
-    this->list.removeAt(index_);
+    emit this->preItemRemoved(index);
+    this->list.removeAt(index);
     emit this->postItemRemoved();
 
     return true;
@@ -218,19 +214,19 @@ bool TracksModel::update(const QVariantMap &data, const int &index)
     if (index >= this->list.size() || index < 0)
         return false;
 
-    const auto index_ = this->mappedIndex(index);
-
-    auto newData = this->list[index_];
+    auto newData = this->list[index];
     QVector<int> roles;
-
-    for (auto key : data.keys())
+    const auto keys = data.keys();
+    for (const auto &key : keys)
+    {
         if (newData[FMH::MODEL_NAME_KEY[key]] != data[key].toString()) {
             newData.insert(FMH::MODEL_NAME_KEY[key], data[key].toString());
             roles << FMH::MODEL_NAME_KEY[key];
         }
+    }
 
-    this->list[index_] = newData;
-    emit this->updateModel(index_, roles);
+    this->list[index] = newData;
+    emit this->updateModel(index, roles);
     return true;
 }
 
