@@ -40,10 +40,10 @@ signals:
     void missingFiles(QStringList urls);
 
 public slots:
-    void copy(const TracksModel *model);
     void append(const QVariantMap &item);
     void appendAt(const QVariantMap &item, const int &at);
     void appendQuery(const QString &query);
+    void copy(const TracksModel *list);
 
     void clear();
     bool fav(const int &index, const bool &value);
