@@ -93,84 +93,6 @@ const static QUrl CachePath = QUrl::fromLocalFile(QStandardPaths::writableLocati
 const static QString DBName = QStringLiteral("collection.db");
 const static QStringList defaultSources = QStringList() << FMStatic::MusicPath << FMStatic::DownloadsPath;
 
-const static inline QString fixTitle(const QString &title, const QString &s, const QString &e)
-{
-    QString newTitle;
-    for (int i = 0; i < title.size(); i++)
-        if (title.at(i) == s) {
-            while (title.at(i) != e)
-                if (i == title.size() - 1)
-                    break;
-                else
-                    i++;
-
-        } else
-            newTitle += title.at(i);
-
-    return newTitle.simplified();
-}
-
-const static inline QString removeSubstring(const QString &newTitle, const QString &subString)
-{
-    const int indexFt = newTitle.indexOf(subString, 0, Qt::CaseInsensitive);
-
-    if (indexFt != -1)
-        return newTitle.left(indexFt).simplified();
-    else
-        return newTitle;
-}
-
-const static inline QString ucfirst(const QString &str) /*uppercase first letter*/
-{
-    if (str.isEmpty())
-        return "";
-
-    QStringList tokens;
-    QStringList result;
-    QString output;
-
-    if (str.contains(" ")) {
-        tokens = str.split(" ");
-
-        for (auto str : tokens) {
-            str = str.toLower();
-            str[0] = str[0].toUpper();
-            result << str;
-        }
-
-        output = result.join(" ");
-    } else
-        output = str;
-
-    return output.simplified();
-}
-
-const static inline QString fixString(const QString &str)
-{
-    // title.remove(QRegExp(QString::fromUtf8("[·-`~!@#$%^&*()_—+=|:;<>«»,.?/{}\'\"\\\[\\\]\\\\]")));
-    QString title = str;
-    title = title.remove(QChar::Null);
-    title = title.contains(QChar('\u0000')) ? title.replace(QChar('\u0000'), "") : title;
-    title = title.contains("(") && title.contains(")") ? fixTitle(title, "(", ")") : title;
-    title = title.contains("[") && title.contains("]") ? fixTitle(title, "[", "]") : title;
-    title = title.contains("{") && title.contains("}") ? fixTitle(title, "{", "}") : title;
-    title = title.contains("ft", Qt::CaseInsensitive) ? removeSubstring(title, "ft") : title;
-    title = title.contains("ft.", Qt::CaseInsensitive) ? removeSubstring(title, "ft.") : title;
-    title = title.contains("featuring", Qt::CaseInsensitive) ? removeSubstring(title, "featuring") : title;
-    title = title.contains("feat", Qt::CaseInsensitive) ? removeSubstring(title, "feat") : title;
-    title = title.contains("official video", Qt::CaseInsensitive) ? removeSubstring(title, "official video") : title;
-    title = title.contains("live", Qt::CaseInsensitive) ? removeSubstring(title, "live") : title;
-    title = title.contains("...") ? title.replace("...", "") : title;
-    title = title.contains("|") ? title.replace("|", "") : title;
-    title = title.contains("|") ? removeSubstring(title, "|") : title;
-    title = title.contains('"') ? title.replace('"', "") : title;
-    title = title.contains(":") ? title.replace(":", "") : title;
-    //    title=title.contains("&")? title.replace("&", "and"):title;
-    // qDebug()<<"fixed string:"<<title;
-
-    return ucfirst(title).simplified();
-}
-
 static inline BAE::TABLE albumType(const FMH::MODEL &albumMap)
 {
     if (albumMap[FMH::MODEL_KEY::ALBUM].isEmpty() && !albumMap[FMH::MODEL_KEY::ARTIST].isEmpty())
